%define module	docutils

%{?build_emacs}%{?!build_emacs:%bcond_without emacs}

Name:		python-%{module}
Summary:	Python Documentation Utilities
Version:	0.14
Release:	1
Source:		http://downloads.sourceforge.net/project/docutils/docutils/0.14/docutils-%{version}.tar.gz
URL:		http://docutils.sourceforge.net/
License:	BSD
Group:		Development/Python
BuildArch:	noarch
BuildRequires:	python
BuildRequires:	python3
%if %{with emacs}
BuildRequires:	emacs
%endif
Requires:	python-roman
Suggests:	python-imaging
Requires(post,preun):	update-alternatives


%description
The purpose of the Docutils project is to create a set of tools for
processing plaintext documentation into useful formats, such as HTML,
XML, and LaTeX.  Support for the following sources has been implemented:

* Standalone files.
* PEPs (Python Enhancement Proposals)

Support for the following sources is planned:

* Inline documentation from Python modules and packages, extracted
  with namespace context.
* Email (RFC-822 headers, quoted excerpts, signatures, MIME parts).
* Wikis, with global reference lookups of "wiki links".
* Compound documents, such as multiple chapter files merged into a
  book.
* And others as discovered.


%package -n     python3-%{module}
Summary:	Python Documentation Utilities
Requires:	python3-roman
Suggests:	python3-imaging


%description -n python3-%{module}
The purpose of the Docutils project is to create a set of tools for
processing plaintext documentation into useful formats, such as HTML,
XML, and LaTeX.  Support for the following sources has been implemented:

* Standalone files.
* PEPs (Python Enhancement Proposals)

Support for the following sources is planned:

* Inline documentation from Python modules and packages, extracted
  with namespace context.
* Email (RFC-822 headers, quoted excerpts, signatures, MIME parts).
* Wikis, with global reference lookups of "wiki links".
* Compound documents, such as multiple chapter files merged into a
  book.
* And others as discovered.


%if %{with emacs}
%package -n     emacs-rst-mode
Summary:	RST mode for emacs


%description -n emacs-rst-mode
emacs mode for editing files in reStructuredText format (RST)
%endif


%prep
%setup -q -n %{module}-%{version}
# Remove shebang from non-executable files
for i in {'code_analyzer','error_reporting','punctuation_chars','smartquotes','math/latex2mathml','math/math2html','math/tex2mathml_extern'}; do
sed -i -e "1d" "docutils/utils/$i.py"
done
sed -i -e "1d" "docutils/writers/xetex/__init__.py" "docutils/writers/_html_base.py"


%build
%py2_build
%py3_build


%install
%py2_install
for file in %{buildroot}%{_bindir}/*.py; do
  mv $file %{buildroot}%{_bindir}/`basename $file .py`-%{python2_version}
done

%py3_install
for file in %{buildroot}%{_bindir}/*.py; do
  mv $file %{buildroot}%{_bindir}/`basename $file .py`-%{py3_ver}
done

%if %{with emacs}
# Make emacs mode available:
emacs -batch -f batch-byte-compile tools/editors/emacs/rst.el
install -d -m 755 %{buildroot}%{_datadir}/emacs/site-lisp
install -D -m 644 tools/editors/emacs/rst.el* %{buildroot}%{_datadir}/emacs/site-lisp
rm -rf tools/editors/emacs

cat > ./rst.el << EOF
(autoload 'rst-mode "rst" "reStructuredText mode" t)
(add-to-list 'auto-mode-alist '("\\.rst$" . rst-mode))
EOF
emacs -batch -f batch-byte-compile rst.el
install -d -m 755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
install -m 644 rst.el* %{buildroot}%{_sysconfdir}/emacs/site-start.d/
%endif


%files
%doc *.txt docs tools
%{py_puresitedir}/*
%{_bindir}/rst*-%{python2_version}


%files -n python3-%{module}
%doc *.txt docs tools
%{py3_puresitedir}
%{_bindir}/*-%{py3_ver}


%if %{with emacs}
%files -n emacs-rst-mode
%{_datadir}/emacs/site-lisp/*
%{_sysconfdir}/emacs/site-start.d/*
%endif


%post
for fn in %{_bindir}/*-%{python2_version}
do
/usr/sbin/update-alternatives --install %{_bindir}/%{fn} %{fn} %{_bindir}/%{fn}-%{python2_version} 20
done


%post -n python3-%{module}
for fn in %{_bindir}/*-%{py3_ver}
do
/usr/sbin/update-alternatives --install %{_bindir}/%{fn} %{fn} %{_bindir}/%{fn}-%{py3_ver} 10
done


%postun
for fn in %{_bindir}/*-%{python2_version}
do
[[ ! -f %{_bindir}/%{fn}-%{python2_version} ]] && \
	/usr/sbin/update-alternatives --remove %{fn} %{_bindir}/%{fn}-%{python2_version}|| :
done


%postun -n python3-%{module}
for fn in %{_bindir}/*-%{py3_ver}
do
[[ ! -f %{_bindir}/%{fn}-%{py3_ver} ]] && \
	/usr/sbin/update-alternatives --remove %{fn} %{_bindir}/%{fn}-%{py3_ver}|| :
done

%changelog

* Fri Dec 29 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.14-1
- (7899146) Move python3-* requirements to python3 subpackage


